import{s as r,c as s,a as t,C as a}from"./chunk-A2AXSNBT-Co8Zfrpr.js";import{_ as e}from"./mermaid-BGnxfgCD.js";import"./transform-DjHZbYKP.js";import"./chunk-RZ5BOZE2-gqSVpaRG.js";import"./index-D3XtisvU.js";import"./step-BwsUM5iJ.js";import"./timer-DFzT7np-.js";var o={parser:t,get db(){return new a},renderer:s,styles:r,init:e((r=>{r.class||(r.class={}),r.class.arrowMarkerAbsolute=r.arrowMarkerAbsolute}),"init")};export{o as diagram};
