import{d as t,L as s,j as i,E as o,C as r,a as p}from"./index-D3XtisvU.js";import{l as m,a as j}from"./index-CVDTCVTM.js";import"./index-Dp1UlEue.js";import"./index-C5qq019G.js";import"./index-CHikDVPK.js";import"./index-G0VFubTN.js";import"./index-DhYqkk4c.js";import"./index-D3MhxVn3.js";import"./index-CNDjQ5fe.js";import"./index-CcWoIc_r.js";import"./index-DNj9MLhG.js";import"./index-D4PFrLQX.js";import"./index-BbzuPatt.js";import"./index-DvyY1C0d.js";import"./apl-CXdQSnD-.js";import"./asciiarmor-D5V0T9Cu.js";import"./asterisk-B46aRdXb.js";import"./brainfuck-CtZaYBKt.js";import"./clike-BgBwzOhw.js";import"./cmake-DXn5xaP-.js";import"./cobol-stawOqaz.js";import"./coffeescript-BTDxI-eT.js";import"./commonlisp-vq6DHwts.js";import"./crystal-CRzZ78HM.js";import"./cypher-gJDei3ni.js";import"./d-BShv7fp-.js";import"./diff-UJJ5BM9S.js";import"./dockerfile-knGOOxt4.js";import"./simple-mode-C3vEBAcb.js";import"./dtd-DI9Herc-.js";import"./dylan-CHJ5qNM_.js";import"./ebnf-B-Df8AvO.js";import"./ecl-DPFc0Uaf.js";import"./eiffel-DR5c0IrL.js";import"./elm-D7xaZ7Da.js";import"./erlang-BuqgqA5h.js";import"./factor-CFXhaUWb.js";import"./fcl-CVaBTCzQ.js";import"./forth-Dri_5nFc.js";import"./fortran-DL7KluxX.js";import"./gas-5kEe4nk0.js";import"./gherkin-B6X1vGSW.js";import"./groovy-DnIzCrpZ.js";import"./haskell-CmdsSjFB.js";import"./haxe-D25e-2l-.js";import"./http-BKJkqRj4.js";import"./idl-pcmmZuaN.js";import"./jinja2-DhgKlfW7.js";import"./julia-DjdwvFuI.js";import"./livescript-HO6ttBFx.js";import"./lua-8DXOpKDz.js";import"./mathematica-IIbmv7SK.js";import"./mbox-DoeuZPxA.js";import"./mirc-DkvFAiy5.js";import"./modelica-DSrSSXCg.js";import"./mscgen-B2igx18G.js";import"./mumps-zvxmGV4l.js";import"./nginx-B4hAVlXN.js";import"./nsis-BvKfQ9lQ.js";import"./ntriples-FFvkTduk.js";import"./octave-C4hdQ5Hf.js";import"./oz-qQq7irPq.js";import"./pascal-CafrKXZF.js";import"./perl-tdMlh9QA.js";import"./pig-CwGJVRC4.js";import"./powershell-D1ly3AHC.js";import"./properties-_nPj978X.js";import"./protobuf-B4y9do6W.js";import"./puppet-Bc-yJKzi.js";import"./q-B0kTJ4cI.js";import"./r-BA4EbLKE.js";import"./ruby-CR-u2WLS.js";import"./sas-Bqaci40L.js";import"./scheme-qjP0V5Ag.js";import"./shell-BLav31RL.js";import"./sieve-r025o_jW.js";import"./smalltalk-C7J3IyEP.js";import"./solr-78MBEUkU.js";import"./sparql-BRLJFz69.js";import"./spreadsheet-CGlWr0eM.js";import"./stylus-OdhglgkO.js";import"./swift-B_XXVlXX.js";import"./tcl-B2fODqDH.js";import"./textile-BuVhTOzU.js";import"./tiddlywiki-BgR6AEZu.js";import"./tiki-CI-ztowC.js";import"./toml-BQXy8elZ.js";import"./troff-Ce85hlLp.js";import"./ttcn-BxnYHtq8.js";import"./turtle-BkSuIpt-.js";import"./vb-BHgjm0DN.js";import"./vbscript-Dawdd5GZ.js";import"./velocity-BdD_26Jv.js";import"./verilog-B4LBqg_1.js";import"./vhdl-CWWH2SUo.js";import"./webidl-CGwyPRYs.js";import"./xquery-CVDBqZPY.js";import"./yacas-I8QjZlxf.js";import"./z80-D8p3gKXp.js";const e=e=>{const a=t.c(26);let l,n,d,c,u;a[0]!==e?(({language:l,showCopyButton:d,extensions:c,...n}=e),a[0]=e,a[1]=l,a[2]=n,a[3]=d,a[4]=c):(l=a[1],n=a[2],d=a[3],c=a[4]),a[5]!==c?(u=void 0===c?[]:c,a[5]=c,a[6]=u):u=a[6];const x=u,f=l&&!(l in j);let g;f&&s.warn(`Language ${l} not found in CodeMirror.`);t:{if(!l){g=x;break t}const t=l;let s,i;a[7]!==t?(s=m(t),a[7]=t,a[8]=s):s=a[8],a[9]!==x||a[10]!==s?(i=[s,...x].filter(Boolean),a[9]=x,a[10]=s,a[11]=i):i=a[11],g=i}const h=g;let v,b,k,y;return a[12]!==f||a[13]!==l?(v=f&&i.jsx(o,{className:"mb-1 rounded-sm",error:`Language ${l} not supported. \n\nSupported languages are: ${Object.keys(j).join(", ")}`}),a[12]=f,a[13]=l,a[14]=v):v=a[14],a[15]!==f||a[16]!==n||a[17]!==d?(b=d&&!f&&i.jsx(r,{tooltip:!1,className:"absolute top-2 right-2 p-1 hover-action z-10 text-muted-foreground",value:n.value||"",toastTitle:"Copied to clipboard"}),a[15]=f,a[16]=n,a[17]=d,a[18]=b):b=a[18],a[19]!==h||a[20]!==n?(k=i.jsx(p,{...n,extensions:h}),a[19]=h,a[20]=n,a[21]=k):k=a[21],a[22]!==v||a[23]!==b||a[24]!==k?(y=i.jsxs("div",{className:"relative w-full group hover-actions-parent",children:[v,b,k]}),a[22]=v,a[23]=b,a[24]=k,a[25]=y):y=a[25],y};export{e as default};
