import{H as r,ay as a,bO as n,bP as t,x as o,P as s,bQ as e,au as u,ai as i,bR as f,at as l,aw as v}from"./index-D3XtisvU.js";import{a as c}from"./_baseEach-DHNYGtOc.js";import{d as b}from"./_baseUniq-BlNMZyiw.js";import{b as p}from"./_baseMap-BXW0_SVK.js";var h=Object.prototype,m=h.hasOwnProperty,d=r((function(r,o){r=Object(r);var s=-1,e=o.length,u=e>2?o[2]:void 0;for(u&&a(o[0],o[1],u)&&(e=1);++s<e;)for(var i=o[s],f=n(i),l=-1,v=f.length;++l<v;){var c=f[l],b=r[c];(void 0===b||t(b,h[c])&&!m.call(r,c))&&(r[c]=i[c])}return r}));function j(r){var a=null==r?0:r.length;return a?r[a-1]:void 0}var O=Math.max;var g,y=(g=function(r,a,n){var t=null==r?0:r.length;if(!t)return-1;var o=null==n?0:e(n);return o<0&&(o=O(t+o,0)),b(r,c(a),o)},function(r,a,n){var t=Object(r);if(!o(r)){var e=c(a);r=s(r),a=function(r){return e(t[r],r,t)}}var u=g(r,a,n);return u>-1?t[e?r[u]:u]:void 0});function x(r,a){return(i(r)?u:p)(r,c(a))}var P=Object.prototype.hasOwnProperty;function w(r,a){return null!=r&&P.call(r,a)}function _(r,a){return null!=r&&f(r,a,w)}function M(r,a){return r<a}function U(r,a,n){for(var t=-1,o=r.length;++t<o;){var s=r[t],e=a(s);if(null!=e&&(void 0===u?e==e&&!l(e):n(e,u)))var u=e,i=s}return i}function q(r){return r&&r.length?U(r,v,M):void 0}export{M as a,U as b,q as c,d,y as f,_ as h,j as l,x as m};
