import{s as r,b as t,a as s,S as e}from"./chunk-AEK57VVT-Y72Hn9sV.js";import{_ as a}from"./mermaid-BGnxfgCD.js";import"./transform-DjHZbYKP.js";import"./chunk-RZ5BOZE2-gqSVpaRG.js";import"./index-D3XtisvU.js";import"./step-BwsUM5iJ.js";import"./timer-DFzT7np-.js";var o={parser:s,get db(){return new e(2)},renderer:t,styles:r,init:a((r=>{r.state||(r.state={}),r.state.arrowMarkerAbsolute=r.arrowMarkerAbsolute}),"init")};export{o as diagram};
