import{b as n,a as r}from"./_baseEach-DHNYGtOc.js";import{ai as t}from"./index-D3XtisvU.js";function a(n,r,t,a){for(var o=-1,u=null==n?0:n.length;++o<u;){var i=n[o];r(a,i,t(i),n)}return a}function o(r,t,a,o){return n(r,(function(n,r,u){t(o,n,a(n),u)})),o}function u(n,u){return function(i,e){var f=t(i)?a:o,c=u?u():{};return f(i,n,r(e),c)}}export{u as c};
