import{c8 as n,c9 as r,ca as t,P as u,cb as e,cc as a,cd as i,ce as c,av as f,cf as o,aw as s,ai as v,cg as l,x as b}from"./index-D3XtisvU.js";function d(n){return n==n&&!t(n)}function g(n,r){return function(t){return null!=t&&(t[n]===r&&(void 0!==r||n in Object(t)))}}function j(t){var e=function(n){for(var r=u(n),t=r.length;t--;){var e=r[t],a=n[e];r[t]=[e,a,d(a)]}return r}(t);return 1==e.length&&e[0][2]?g(e[0][0],e[0][1]):function(u){return u===t||function(t,u,e,a){var i=e.length,c=i;if(null==t)return!c;for(t=Object(t);i--;){var f=e[i];if(f[2]?f[1]!==t[f[0]]:!(f[0]in t))return!1}for(;++i<c;){var o=(f=e[i])[0],s=t[o],v=f[1];if(f[2]){if(void 0===s&&!(o in t))return!1}else{var l=new n;if(!r(v,s,3,a,l))return!1}}return!0}(u,0,e)}}function h(n){return e(n)?o(a(n)):function(n){return function(r){return f(r,n)}}(n)}function p(n){return"function"==typeof n?n:null==n?s:"object"==typeof n?v(n)?(t=n[0],u=n[1],e(t)&&d(u)?g(a(t),u):function(n){var e=i(n,t);return void 0===e&&e===u?c(n,t):r(u,e,3)}):j(n):h(n);var t,u}function x(n,r){return n&&l(n,r,u)}var O,m=(O=x,function(n,r){if(null==n)return n;if(!b(n))return O(n,r);for(var t=n.length,u=-1,e=Object(n);++u<t&&!1!==r(e[u],u,e););return n});export{p as a,m as b,x as c};
